@@ -8,7 +8,7 @@ class Notifier:
         self.isActive = False
 
         if get_asset_property(asset_name="go_manager", property="brokers") is not None:
-            self.producer = KafkaProducer(bootstrap_servers=[get_asset_property(asset_name="go_manager", property="brokers").split(",")])
+            self.producer = KafkaProducer(bootstrap_servers=get_asset_property(asset_name="go_manager", property="brokers").split(","))
             self.topic = get_asset_property(asset_name="go_manager", property="topic")
             self.isActive = True
 
